==> haskell-ranged-sets-0.4.0-230-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Ranged-sets
version:              0.4.0
visibility:           public
id:                   Ranged-sets-0.4.0-6DwlodZCoDIAJ86RAKmok2
key:                  Ranged-sets-0.4.0-6DwlodZCoDIAJ86RAKmok2
license:              BSD-3-Clause
copyright:            Paul Johnson, 2005, 2006, 2007, 2008, 2019
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Ranged-sets
synopsis:             Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:

    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)

    Alternatively you can have all strings s such that:

    >    ("F" <= s < "G")

category:             Data
abi:                  9f49fcf857f607c65f5d42be2ce11337
exposed:              True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges

import-dirs:          /usr/lib/ghc-9.2.8/site-local/Ranged-sets-0.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/Ranged-sets-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ranged-sets
hs-libraries:         HSRanged-sets-0.4.0-6DwlodZCoDIAJ86RAKmok2
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0

haddock-interfaces:   /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html:         /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ranged-sets-0.4.0-258.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ranged-sets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Ranged-sets
version:              0.4.0
visibility:           public
id:                   Ranged-sets-0.4.0-40p9dcG2ogkDEqPodNKxp0
key:                  Ranged-sets-0.4.0-40p9dcG2ogkDEqPodNKxp0
license:              BSD-3-Clause
copyright:            Paul Johnson, 2005, 2006, 2007, 2008, 2019
maintainer:           paul@cogito.org.uk
author:               Paul Johnson
stability:            beta
homepage:             https://github.com/PaulJohnson/Ranged-sets
synopsis:             Ranged sets for Haskell
description:
    A ranged set is an ordered list of ranges.  This allows sets such as all reals x such that:

    > (0.25 < x <= 0.75 or 1.4 <= x < 2.3 or 4.5 < x)

    Alternatively you can have all strings s such that:

    >    ("F" <= s < "G")

category:             Data
abi:                  ab3f74bb21e433707aafc3e8945249ca
exposed:              True
exposed-modules:
    Data.Ranged Data.Ranged.Boundaries Data.Ranged.RangedSet
    Data.Ranged.Ranges

import-dirs:          /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/Ranged-sets-0.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ranged-sets
hs-libraries:         HSRanged-sets-0.4.0-40p9dcG2ogkDEqPodNKxp0
depends:
    HUnit-1.6.2.0-DucYFi7W996LJfea0vxExR
    QuickCheck-2.14.3-Gpw9UoHUxB71c0Trj8n39O base-4.17.2.1

haddock-interfaces:   /usr/share/doc/haskell-ranged-sets/html/Ranged-sets.haddock
haddock-html:         /usr/share/doc/haskell-ranged-sets/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
